Test Problems
=============

Eight Puzzle
------------

.. automodule:: py_search.problems.eight_puzzle
    :members:
    :undoc-members:
    :show-inheritance:

N-Queens Problem
----------------

.. automodule:: py_search.problems.nqueens
    :members:
    :undoc-members:
    :show-inheritance:

Assignment Problem
------------------

.. automodule:: py_search.problems.assignment_problem
    :members:
    :undoc-members:
    :show-inheritance:

Graph Partition Problem
-----------------------

.. automodule:: py_search.problems.graph_partition
    :members:
    :undoc-members:
    :show-inheritance:
